Re: [OpenWrt-Devel] [brcm63xx] Re: source code / disassembler / decompiler

2013-01-31 Thread Christoph Thielecke
Hiho,

  hmmm, correct me but the drivers are GPL licenced (automatically) because
  they are shipped with a GPL-kernel. only problem is you havent the
  source. so simply make it and release anonymously? 8-) if you care i
  will do. i'am sure no one will complain...
I would be become happy if acx100 (http://acx100.sourceforge.net/, driver for 
TNETW1130 (ACX111) / TNETW1100 (ACX100) / TNETW1450) would be a clean gpl 
source and ready to integrate into mainline.
This driver has same problem :(

Or is there are still a solution yet?

Still using very old avm driver (on very old kernel) for avm fritz wlan usb on 
testmachine :(


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] acx-mac80211 (was Re: [brcm63xx] Re: source code / disassembler / decompiler)

2013-01-31 Thread Christoph Thielecke
Hello,

  I would be become happy if acx100 (http://acx100.sourceforge.net/, driver
  for TNETW1130 (ACX111) / TNETW1100 (ACX100) / TNETW1450) would be a clean
  gpl source and ready to integrate into mainline.
  This driver has same problem :(

 It is my understanding that Lantiq determined that they now own the
 rights to the proprietary code that leaked into the acx-mac80211 driver
 and gave OpenWrt the official go-ahead to use it under the GPL. I could
 be wrong, but AFAIK, the status of this driver is no longer an issue.
If that is true,  Rafał maybe could help to get it into mainline :)

 What IS still an issue is the lack of a usable driver for the
 TNETW1350A, because no one has the inclination to write it. The current
 upstream maintainer of acx-mac80211, Oliver Winker, said that such a
 driver would much more closely resemble the wl1251 driver than the acx
 driver, but the wl1251 maintainers know nothing about the TNETW1350A.
:(

Its seems there some devices which have it so it could be useful :)


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] new package: openvpn-interface

2013-01-14 Thread Christoph Thielecke
Hello,

 I have created a bundle with the required files (quite a lot, because of
 many up- down- connect- and disconnect- scripts) here:
 http://www.schlipper.net/openwrt/openvpn-interface.tgz
Its password protected which is surely wrong.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] Build WifiDog against OpenWrt Backfire?

2012-07-25 Thread Christoph Thielecke
Hello,

 I'm trying to build ipkg package of WifiDog from source,
Already packaged :)

 based on the 
 tutorial http://dev.wifidog.org/wiki/doc/install/gateway
 but the command
 make ipk
 does not work. It said that ipk rule does not exist.
 So, how can I build it?

 The WifiDog author has stopped working on building WifiDog for long time
 so he cannot help me. I think OpenWrt package maintainers successfully
 build it. So hope you can help.
Use this dir inside packages dir on backfire:
https://dev.openwrt.org/browser/packages/net/wifidog


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] bcm63xx adsl modem support status

2012-06-06 Thread Christoph Thielecke
Hello,

whats the current status of bcm63xx adsl modems (e.g. inside d-link dsl-2741)?

Anything news or success?


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] [PATCH] compcache compile fix linux 2.6.38

2012-04-26 Thread Christoph Thielecke
Hello,

I just build trunk and the compcache package was enabled and failed to build. 
After some research I found that bd_claim/bd_release has been changed with 
commit 
http://git.cmpxchg.org/?p=linux-mmotm.git;a=commitdiff_plain;h=e525fd89d380c4a94c0d63913a1dd1a593ed25e7

Here is the patch and the module compiles again ;)


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/
--- a/ramzswap_drv.c	2012-04-26 14:58:10.017908430 +0200
+++ b/ramzswap_drv.c	2012-04-26 15:08:09.005924115 +0200
@@ -525,7 +525,11 @@
 
 	if (S_ISBLK(inode-i_mode)) {
 		bdev = I_BDEV(inode);
+#if LINUX_VERSION_CODE  KERNEL_VERSION(2, 6, 38)
+		blkdev_get(bdev, FMODE_READ | FMODE_WRITE | FMODE_EXCL, setup_backing_swap);
+#else
 		ret = bd_claim(bdev, setup_backing_swap);
+#endif
 		if (ret  0) {
 			bdev = NULL;
 			goto bad_param;
@@ -557,7 +561,11 @@
 
 bad_param:
 	if (bdev)
+#if LINUX_VERSION_CODE  KERNEL_VERSION(2, 6, 38)
+		blkdev_put(bdev, FMODE_READ | FMODE_WRITE | FMODE_EXCL);
+#else
 		bd_release(bdev);
+#endif
 	filp_close(swap_file, NULL);
 
 out:
@@ -1097,7 +1105,11 @@
 	/* Close backing swap device, if present */
 	if (rzs-backing_swap) {
 		if (is_backing_blkdev)
+#if LINUX_VERSION_CODE  KERNEL_VERSION(2, 6, 38)
+			blkdev_put(rzs-backing_swap, FMODE_READ | FMODE_WRITE | FMODE_EXCL);
+#else
 			bd_release(rzs-backing_swap);
+#endif
 		filp_close(rzs-swap_file, NULL);
 		rzs-backing_swap = NULL;
 		memset(rzs-backing_swap_name, 0, MAX_SWAP_NAME_LEN);


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] valgrind on x86 target: PATCH

2012-04-25 Thread Christoph Thielecke
Hello,

 I tried to run valgrind (3.3.1) on x86 target running. The package was
 build and installed fine (just adapted the /usr/lib/valgrind/uclibc.supp to
 ld-uClibc-0.9.29.so). But running valgrind gives:

 root@OpenWrt:/tmp# valgrind -d
 --5329:1:debuglog DebugLog system started by Stage 1, level 1 logging
 requested
 --5329:1:launcher no tool requested, defaulting to 'memcheck'
 --5329:1:launcher no client specified, defaulting platform to 'x86-linux'
 --5329:1:launcher launching /usr/lib/valgrind/x86-linux/memcheck
 valgrind: failed to start tool 'memcheck' for platform 'x86-linux': No such
 file or directory


 What could be wrong? I tried to set VALGRIND_LIB, LD_LIBRARY_PATH and so on
 but memcheck work start :(

 I'm lucky forward to any useful hints.

After some resarch I found the reason:

Valgrind was compiled with wrong flags:

$(MAKE) -C $(PKG_BUILD_DIR) \
$(TARGET_CONFIGURE_OPTS) \
DESTDIR=$(PKG_INSTALL_DIR) \
CFLAGS=$(TARGET_CFLAGS) \
AM_CFLAGS_X86_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \ 
AM_CFLAGS_AMD64_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \         
      
AM_CFLAGS_PPC32_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \
AM_CFLAGS_PPC64_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \
TOOL_LDADD_COMMON=$(LIBGCC_A) $(PKG_BUILD_DIR)/abort.a
all install

I changed it to:
$(MAKE) -C $(PKG_BUILD_DIR) \
$(TARGET_CONFIGURE_OPTS) \
DESTDIR=$(PKG_INSTALL_DIR) \
CFLAGS=$(TARGET_CFLAGS) -m32 -mpreferred-stack-boundary=2 -O -g 
-Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith-Wstrict-proto 
\
all install


Now it works (I had to symlink /usr/lib/valgrind/x86-linux/uclibc.supp 
to /usr/lib/valgrind/x86-linux/default.supp):
root@OpenWrt:~# valgrind ls
==4369== Memcheck, a memory error detector.
==4369== Copyright (C) 2002-2007, and GNU GPL'd, by Julian Seward et al.
==4369== Using LibVEX rev 1854, a library for dynamic binary translation.
==4369== Copyright (C) 2004-2007, and GNU GPL'd, by OpenWorks LLP.
==4369== Using valgrind-3.3.1, a dynamic binary instrumentation framework.
==4369== Copyright (C) 2000-2007, and GNU GPL'd, by Julian Seward et al.
==4369== For more details, rerun with: -v
==4369==
==4369==
==4369== ERROR SUMMARY: 0 errors from 0 contexts (suppressed: 0 from 0)
==4369== malloc/free: in use at exit: 0 bytes in 0 blocks.
==4369== malloc/free: 0 allocs, 0 frees, 0 bytes allocated.
==4369== For counts of detected errors, rerun with: -v
==4369== All heap blocks were freed -- no leaks are possible.

The resulting patch is attached. It contains the flags change, support for 3.x 
kernel on host and the missing symlink to default.supp

Happy memchecking ;)


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/
diff -burN openwrt-package-feeds/utils/valgrind/files/uclibc.supp valgrind/files/uclibc.supp
--- openwrt-package-feeds/utils/valgrind/files/uclibc.supp	2009-04-03 09:56:58.0 +0200
+++ valgrind/files/uclibc.supp	2012-04-25 09:58:35.0 +0200
@@ -201,12 +201,12 @@
 {
insert a suppression name here
Memcheck:Addr2
-   obj:/lib/ld-uClibc-0.9.28.so
+   obj:/lib/ld-uClibc-0.9.29.so
fun:*
 }
 {
insert a suppression name here
Memcheck:Addr4
-   obj:/lib/ld-uClibc-0.9.28.so
+   obj:/lib/ld-uClibc-0.9.29.so
fun:*
 }
diff -burN openwrt-package-feeds/utils/valgrind/Makefile valgrind/Makefile
--- openwrt-package-feeds/utils/valgrind/Makefile	2012-04-25 09:57:21.003173253 +0200
+++ valgrind/Makefile	2012-04-25 10:25:39.315217728 +0200
@@ -52,12 +52,7 @@
 	$(MAKE) -C $(PKG_BUILD_DIR) \
 		$(TARGET_CONFIGURE_OPTS) \
 		DESTDIR=$(PKG_INSTALL_DIR) \
-		CFLAGS=$(TARGET_CFLAGS) \
-		AM_CFLAGS_X86_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \
-		AM_CFLAGS_AMD64_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \
-		AM_CFLAGS_PPC32_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \
-		AM_CFLAGS_PPC64_LINUX=$(TARGET_CFLAGS) -I$(PKG_BUILD_DIR)/coregrind \
-		TOOL_LDADD_COMMON=$(LIBGCC_A) $(PKG_BUILD_DIR)/abort.a \
+		CFLAGS=$(TARGET_CFLAGS) -m32 -mpreferred-stack-boundary=2 -O -g -Wmissing-prototypes -Winline -Wall -Wshadow -Wpointer-arith-Wstrict-proto \
 		all install
 endef
 
@@ -66,8 +61,10 @@
 	$(INSTALL_BIN) $(PKG_INSTALL_DIR)/usr/bin/* $(1)/usr/bin/
 	$(INSTALL_BIN) ./files/valgrind.sh $(1)/usr/bin/
 	$(INSTALL_DIR) $(1)/usr/lib/valgrind
-	$(CP) ./files/uclibc.supp $(1)/usr/lib/valgrind/
 	$(CP) $(PKG_INSTALL_DIR)/usr/lib/valgrind/*-linux $(1)/usr/lib/valgrind/
+	$(CP) ./files/uclibc.supp $(1)/usr/lib/valgrind/
+	cd $(1)/usr/lib/valgrind/  ln -s uclibc.supp default.supp
+
 endef
 
 $(eval $(call BuildPackage,valgrind))
diff -burN openwrt-package-feeds/utils/valgrind/patches/000-kernel_3.x.patch valgrind/patches/000-kernel_3.x.patch
--- openwrt-package-feeds/utils/valgrind/patches/000-kernel_3.x.patch	1970-01-01 01:00:00.0 +0100
+++ valgrind/patches/000-kernel_3.x.patch	2012-04-16 19:06:38.0 +0200
@@ -0,0 +1,51 @@
+--- /dev/null
 

[OpenWrt-Devel] valgrind on x86 target

2012-04-24 Thread Christoph Thielecke
Hello,

I tried to run valgrind (3.3.1) on x86 target running. The package was build 
and installed fine (just adapted the /usr/lib/valgrind/uclibc.supp to 
ld-uClibc-0.9.29.so). But running valgrind gives:

root@OpenWrt:/tmp# valgrind -d
--5329:1:debuglog DebugLog system started by Stage 1, level 1 logging 
requested
--5329:1:launcher no tool requested, defaulting to 'memcheck'
--5329:1:launcher no client specified, defaulting platform to 'x86-linux'
--5329:1:launcher launching /usr/lib/valgrind/x86-linux/memcheck
valgrind: failed to start tool 'memcheck' for platform 'x86-linux': No such 
file or directory

The files are there on right place:
root@OpenWrt:/tmp# ls -l /usr/lib/valgrind/x86-linux/*
-rwxr-xr-x1 root root  2441048 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/cachegrind
-rwxr-xr-x1 root root  2530502 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/callgrind
-rwxr-xr-x1 root root  2440404 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/exp-drd
-rwxr-xr-x1 root root  2401593 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/exp-omega
-rwxr-xr-x1 root root  2502779 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/helgrind
-rwxr-xr-x1 root root  2393905 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/lackey
-rw-r--r--1 root root  1088112 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/libcoregrind.a
-rw-r--r--1 root root  2528598 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/libvex.a
-rwxr-xr-x1 root root  2413309 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/massif
-rwxr-xr-x1 root root  2490592 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/memcheck
-rwxr-xr-x1 root root  2384143 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/none
-rwxr-xr-x1 root root 4344 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/vgpreload_core.so
-rwxr-xr-x1 root root36703 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/vgpreload_exp-drd.so
-rwxr-xr-x1 root root19507 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/vgpreload_exp-omega.so
-rwxr-xr-x1 root root59884 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/vgpreload_helgrind.so
-rwxr-xr-x1 root root15337 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/vgpreload_massif.so
-rwxr-xr-x1 root root39934 Apr 24 
19:52 /usr/lib/valgrind/x86-linux/vgpreload_memcheck.so

What could be wrong? I tried to set VALGRIND_LIB, LD_LIBRARY_PATH and so on 
but memcheck work start :(

I'm lucky forward to any useful hints.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] openwrt wiki: media manager

2012-04-04 Thread Christoph Thielecke
Hello,

I just uploaded some pictures in wrong place with the media manager. How I can 
removed the wrong ones?


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] d-link dsl-2741b serial

2012-03-27 Thread Christoph Thielecke
Hello,

I try to get the serial console on a d-link dsl-2741 wrong.

There is a serial port on the board (with pins already). Does someone have the 
pin layout and the settings for it? I found that it should be 115200 (gpl 
source, kernel config: CONFIG_CMDLINE=console=ttyS0,115200

I got some output in some cases but the output is always garbled. I tried 
various speed settings but no success.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] WBMR-HP-G300H flash image for flashing from original FW?

2012-02-27 Thread Christoph Thielecke
Hello,

   It would be make life easier if there is the possibility to flash
   directly from dd-wrt webif.
  
   most likely true... i will investigate how to do so 

  DD-Wrt normally awaits a TRX flash image (HDR0 header) with the
  noheader flag set.
  See https://forum.openwrt.org/viewtopic.php?pid=154817#p154817

 But I'm still unable to flash openwrt from dd-wrt webif if it has the HDR0
 header. It tells me that the firmware is invalid :(
I was wrong, there is the stock FW on the device and not dd-wrt.

 I did some research too and found the images for the device build by
 brainslayer
 (http://www.dd-wrt.com/dd-wrtv2/down.php?path=downloads%2Fothers%2Feko%2FBr
ainSlayer-V24-preSP2%2F2011%2F12-20-11-r18024%2Fbuffalo_whr_hp_g300n/):
 whr-hp-g300n-firmware-MULTI.bin
 The first one (for use with webif) looks completly different.
At dd-wrt svn (src/router/Makefile.danube) I found the values for the 
WBMR-HP-G300H:

tools/bufenc/encryptRC4 WBMR-HP-G300H 1.74 Buffalo  
$(ARCH)-uclibc/aligned.uimage $(ARCH)-uclibc/wmbr-firmware.enc
tools/bufenc/mkfw-lan -hw_ver=2 -hcrypt=Buffalo WBMR-HP-G300H 
WBMR-HP-G300H 1.74 3.02 US-EU-AP-KR-CH-TW-DE-JP mlang8 lan  
80002000 80002000 1 
$(ARCH)-uclibc/wmbr-firmware.enc $(ARCH)-uclibc/wmbr-firmware_MULTI.enc

Ok, tools/bufenc/encryptRC4 seems to be buffalo-enc, tools/bufenc/mkfw-lan 
buffalo-enc.
On the device there are this settings:

# cat /etc/BRAND_NAME
WBMR-HP-G300H

# cat /etc/PRODUCT_NAME
WBMR-HP-G300H

# cat /etc/HW_VERSION
1

# cat /etc/MAJOR_VERSION
1.74

# cat /etc/MINOR_VERSION
3.02

# cat /etc/LANGUAGE
eng-de-fr-it-es-zh_cn-th

# cat /etc/SPECIFICATION
AP-EU-DE

cat /etc/PLATFORM
lan

Depending on this values I adapted the cmd lines from WHRHPG300N 
(target/linux/ar71xx/image/Makefile):
buffalo-enc -p WBMR-HP-G300H -v 1.74 -i 
openwrt-lantiq-ar9-WBMR-squashfs.image -o factory.enc
buffalo-tag -p WBMR-HP-G300H -b WBMR-HP-G300H -a lan -v 1.74 -m 3.02 -l 
mlang8 -w 1 -c 0x80002000 -d 0x80002000 -f 1 -r M_ -i factory.enc -o 
openwrt-lantiq-ar9-WBMR-squashfs-factory_test.trx

Then I tried to flash it via webif. 

Console shows now:
cgi.c(3617) UploadCgi :x:btpd STOP-SUCCESS (0 sec)
cgi.c(3859) UploadCgi :x:MEMORY CHECK...
MidLayer.c(2067) ML_CheckMemory :X:MemFree = 23652
MidLayer.c(2071) ML_CheckMemory :X:Buffers = 4000
MidLayer.c(2075) ML_CheckMemory :X:Cached = 12788
MidLayer.c(2079) ML_CheckMemory :X:Active = 11464
MidLayer.c(2083) ML_CheckMemory :X:Inactive = 7520
cgi.c(4416) UploadCgi :DEBUG:### CFH-mark=WBMR-HP-G300H ###
cgi.c(4460) UploadCgi :DEBUG:### NON-CRYPT ###
cgi.c(4467) UploadCgi :DEBUG:firm_size:2887884  lTotalSize:2887884
cgi.c(4469) UploadCgi :DEBUG:### cyg_posix_crc32 start ###
cgi.c(4471) UploadCgi :DEBUG:### cyg_posix_crc32 end new_CRC32:616818920###
cgi.c(4483) UploadCgi :DEBUG:firm_size:2887884  lCRC32:616818920
cgi.c(4486) UploadCgi :DEBUG:CRC OK !UploadCgi(4486)
cgi.c(4532) UploadCgi :X:ADSL:AnnexB size 1946177280

Upload seems ok but I got a reset from peer - the upgrade script/bin died

I found a image from brainslayer (thread: 
http://www.dd-wrt.com/phpBB2/viewtopic.php?t=148711postdays=0postorder=ascstart=30,
 download: 
http://www.dd-wrt.com/phpBB2/download.php?id=21546, needs registered at dd-wrt 
forum) for comparing.

Maybe someone has a idea whats wrong.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] WBMR-HP-G300H flash image for flashing from original FW?

2012-02-23 Thread Christoph Thielecke
Hello,

 On 23.02.2012 19:21, John Crispin wrote:
  dd-wrt webif

 on openwrt? ..ede
OpenWRT bin image for flashing on dd-wrt webif on first time.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] ARM-Based Hardware with analog phone ports

2012-02-14 Thread Christoph Thielecke
Hello,

 lantiq does however use MIPS as a core. the board are available of ebay
 for very little, i have been testing on DT Speedport w501V and w303V,
 both of which i got for less than 10 euro.
That sounds really cool if OpenWRT can run on w501v.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] openwrt capable router with integrated adsl modem

2012-02-11 Thread Christoph Thielecke
Hello,

I'm searching for a new router which has an integrated adsl (2+) modem and 
runs openwrt (trunk is ok).

What device is recommened?


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] openwrt capable router with integrated adsl modem

2012-02-11 Thread Christoph Thielecke
Hello Philip,

  I'm searching for a new router which has an integrated adsl (2+) modem
  and runs openwrt (trunk is ok).
 
  What device is recommened?
 
 


 I like the Geos box from Traverse Technologies, but that's just me... :-)
Thank you very much. How I can order Geos 1/Geos 2 mainboard? I looked at 
linitx and traverse.kd85.com but found only the pci cards. How much it cost 
Geos1 and how much Geos2?


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] [PATCH] ccache install fix if ccache is locally installed

2012-02-01 Thread Christoph Thielecke
Hello JoW,

 I believe your patch patch just hides the symptom of an actual problem
 with cmake. Where the failing packages ones the use cmake for building?

 If so I believe your issue has been fixed with r29982 .
Yes, you're right, that is really the better way.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] [PATCH] ccache install fix if ccache is locally installed

2012-01-31 Thread Christoph Thielecke
Hello,

I ran into the problem that if ccache is locally installed building some 
programs does not found the compiler. The ccache binary is looked up in 
staging_dir/host/bin which is only there if installed. This patch fixes the 
ccache install if ccache is found.

The patch is against 10.03.1.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/
diff -burN tools/ccache.orig/Makefile tools/ccache/Makefile
--- tools/ccache.orig/Makefile	2012-01-31 19:56:07.456732068 +0100
+++ tools/ccache/Makefile	2012-01-31 20:05:05.200749061 +0100
@@ -38,6 +38,7 @@
   define Host/Compile
   endef
   define Host/Install
+	ln -sf $$(shell which ccache) $(STAGING_DIR_HOST)/bin/ccache
   endef
   define Host/Clean
   endef


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] [PATCH] ccache install fix if ccache is locally installed

2012-01-31 Thread Christoph Thielecke
Hello,

 I ran into the problem that if ccache is locally installed building some
 programs does not found the compiler. The ccache binary is looked up in
 staging_dir/host/bin which is only there if installed. This patch fixes the
 ccache install if ccache is found.

 The patch is against 10.03.1.
The name was a little be wrong, it should be 
ccache_missing_fix_if_ccache_installed.patch


With best regards

Christoph
diff -burN package.orig/dhcp/files/dhclient-script package/dhcp/files/dhclient-script
--- package.orig/dhcp/files/dhclient-script	1970-01-01 01:00:00.0 +0100
+++ package/dhcp/files/dhclient-script	2012-01-26 14:46:50.913128712 +0100
@@ -0,0 +1,160 @@
+#!/bin/sh
+
+. /etc/functions.sh
+include /lib/network
+RESOLV_CONF=/tmp/resolv.conf.auto
+
+change_state () {
+	[ -n $ifc ] || return
+	uci_revert_state $1 $2 $3 $4
+	uci_set_state $1 $2 $3 $4
+}
+
+set_classless_routes() {
+	local max=128
+	local type
+	while [ -n $1 -a -n $2 -a $max -gt 0 ]; do
+		[ ${1##*/} -eq 32 ]  type=host || type=net
+		echo dhclient: adding route for $type $1 via $2
+		route add -$type $1 gw $2 dev $interface
+		max=$(($max-1))
+		shift 2
+	done
+}
+
+setup_interface () {
+	local old_ip
+	local old_broadcast
+	local old_subnet
+	local old_router
+	local old_dns
+	local user_dns
+	local user_router
+	local user_metric
+
+	[ -n $ifc ]  {
+		old_ip=$(uci_get_state network $ifc ipaddr)
+		old_broadcast=$(uci_get_state network $ifc broadcast)
+		old_subnet=$(uci_get_state network $ifc netmask)
+	}
+
+	[ $new_ip_address != $old_ip ] \
+	|| [ ${new_broadcast_address:-+} != $old_broadcast ] \
+	|| [ ${new_subnet_mask:-255.255.255.0} != $old_subnet ]  {
+		echo dhclient: ifconfig $interface $new_ip_address netmask ${new_subnet_mask:-255.255.255.0} broadcast ${new_broadcast_address:-+}
+		ifconfig $interface $new_ip_address netmask ${new_subnet_mask:-255.255.255.0} broadcast ${new_broadcast_address:-+}
+
+		change_state network $ifc ipaddr $new_ip_address
+		change_state network $ifc broadcast ${new_broadcast_address:-+}
+		change_state network $ifc netmask ${new_subnet_mask:-255.255.255.0}
+	}
+
+
+	# Default Route
+	[ -n $ifc ]  {
+		change_state network $ifc lease_gateway $new_routers
+		old_router=$(uci_get_state network $ifc gateway)
+		user_router=$(uci_get network $ifc gateway)
+		user_metric=$(uci_get network $ifc metric)
+		[ -n $user_router ]  router=$user_router
+	}
+
+	[ -n $new_routers ]  [ $new_routers != 0.0.0.0 ]  [ $new_routers != 255.255.255.255 ]  [ $new_routers != $old_router ]  {
+		echo dhclient: setting default routers: $new_routers
+
+		local valid_gw=
+		for i in $new_routers ; do
+			route add default gw $i ${user_metric:+metric $user_metric} dev $interface
+			valid_gw=${valid_gw:+$valid_gw|}$i
+		done
+		
+		eval $(route -n | awk '
+			/^0.0.0.0\W{9}('$valid_gw')\W/ {next}
+			/^0.0.0.0/ {print route del -net $1 gw $2;}
+		')
+
+		change_state network $ifc gateway $new_routers
+	}
+
+	# CIDR STATIC ROUTES (rfc3442)
+	[ -n $staticroutes ]  set_classless_routes $staticroutes
+	[ -n $msstaticroutes ]  set_classless_routes $msstaticroutes
+
+	# DNS
+	old_dns=$(uci_get_state network $ifc dns)
+	

Re: [OpenWrt-Devel] Let's fix the OpenWrt patch acceptance problem!

2012-01-25 Thread Christoph Thielecke
Hello Felix,

 Does this proposal make sense? Do we have any volunteers that are
 willing to organize and take care of maintaining the tree and compile
 testing and reviewing the incoming changes?
I can offer to help with brcm47xx, x86. Also, I working on webif package (just 
for your interest).


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] [PATCH] wait for blockdevice mtd2block (useful for usbboot)

2012-01-25 Thread Christoph Thielecke
Hello,

I'm working on x86 using usb for boot. It works for me if usb and usb-storage 
drivers enabled via make kernel_menuconfig.

One thing I had to fix for get it working: mtd2block does not long enough 
until usb has been up. This patch was made against 2.6.32 at 10.03 (put in  
target/linux/generic-2.6/patches-2.6.32).
This is same as I wrote at https://dev.openwrt.org/ticket/9780

The second one (068-block2mtd_probe.patch, adds the wait for device probe) was 
missing on ticket.

The patch is based on the code at  
http://permalink.gmane.org/gmane.linux.drivers.mtd/26384 (by Tobias 
Diedrich).

Maybe we find a way to integrate usbboot options (enable usb+usb-storage 
directly into kernel if usb boot enabled via option). I'll have a look on 
that later.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/) but 
--- a/drivers/mtd/devices/block2mtd.c
+++ b/drivers/mtd/devices/block2mtd.c
@@ -268,6 +268,7 @@ static int _open_bdev(struct block2mtd_d
 		/* We might not have rootfs mounted at this point. Try
 		   to resolve the device name by other means. */
 
+		wait_for_device_probe();
 		dev_t devt = name_to_dev_t(dev-devname);
 		if (devt) {
 			bdev = open_by_devnum(devt, FMODE_WRITE | FMODE_READ);
--- a/drivers/mtd/devices/block2mtd.c.orig	2011-07-22 10:17:24.006187073 +0200
+++ a/drivers/mtd/devices/block2mtd.c	2011-07-22 10:48:03.706185480 +0200
@@ -18,6 +18,8 @@
 #include linux/buffer_head.h
 #include linux/mutex.h
 #include linux/mount.h
+#include linux/delay.h
+#include linux/kthread.h
 
 #define ERROR(fmt, args...) printk(KERN_ERR block2mtd:  fmt \n , ## args)
 #define INFO(fmt, args...) printk(KERN_INFO block2mtd:  fmt \n , ## args)
@@ -475,7 +477,31 @@
 #endif
 
 
-static int block2mtd_setup2(const char *val)
+struct block2mtd_setupasync_params {
+   char *name;
+   int erase_size;
+   char *mtdname;
+};
+
+static int block2mtd_setupasync(void *p)
+{
+   struct block2mtd_setupasync_params *params = p;
+   int i;
+
+   printk(KERN_WARNING block2mtd: spawned kernel thread for async waiting on '%s'\n, params-name);
+   for (i=0; i20; i++) {
+   msleep(1000);
+
+if (add_device(params-name, params-erase_size, params-mtdname) != NULL)
+   break;
+   }
+   kfree(params-name);
+   kfree(params);
+
+   return 0;
+}
+
+static int block2mtd_setup2(const char *val, int async)
 {
 	char buf[80 + 12 + 80]; /* 80 for device, 12 for erase size, 80 for name */
 	char *str = buf;
@@ -483,6 +509,7 @@
 	char *name;
 	size_t erase_size = PAGE_SIZE;
 	int i, ret;
+	struct block2mtd_setupasync_params *params;
 
 	if (strnlen(val, sizeof(buf)) = sizeof(buf))
 		parse_err(parameter too long);
@@ -512,7 +539,33 @@
 	if (token[2]  (strlen(token[2]) + 1  80))
 		parse_err(mtd device name too long);
 
-	add_device(name, erase_size, token[2]);
+   if (add_device(name, erase_size, token[2]) != NULL)
+   return 0;
+
+   params = kzalloc(sizeof(struct block2mtd_setupasync_params), GFP_KERNEL);
+   if (!params)
+   return 0;
+
+   params-name = kmalloc(strlen(name)+1, GFP_KERNEL);
+   params-erase_size = erase_size;
+   if (!params-name) {
+   kfree(params);
+   return 0;
+   }
+
+   memcpy(params-name, name, strlen(name)+1);
+
+   params-mtdname = kmalloc(strlen(token[2])+1, GFP_KERNEL);
+   
+   if (!params-mtdname) {
+   kfree(params);
+   return 0;
+   }
+
+   memcpy(params-mtdname, token[2], strlen(token[2])+1);
+
+   if (async)
+   kthread_run(block2mtd_setupasync, params, block2mtd/setupasync);
 
 	return 0;
 }
@@ -521,7 +574,7 @@
 static int block2mtd_setup(const char *val, struct kernel_param *kp)
 {
 #ifdef MODULE
-	return block2mtd_setup2(val);
+	return block2mtd_setup2(val, 0);
 #else
 	/* If more parameters are later passed in via
 	   /sys/module/block2mtd/parameters/block2mtd
@@ -529,7 +582,7 @@
 	   we can parse the argument now. */
 
 	if (block2mtd_init_called)
-		return block2mtd_setup2(val);
+		return block2mtd_setup2(val, 0);
 
 	/* During early boot stage, we only save the parameters
 	   here. We must parse them later: if the param passed
@@ -554,7 +607,7 @@
 
 #ifndef MODULE
 	if (strlen(block2mtd_paramline))
-		ret = block2mtd_setup2(block2mtd_paramline);
+		 ret = block2mtd_setup2(block2mtd_paramline, 1);
 	block2mtd_init_called = 1;
 #endif
 


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] x86 sysupgrade

2012-01-23 Thread Christoph Thielecke
Hello Philip,

 For those of us using x86-based platforms we'd like to have a way to do
 in-place upgrades without losing configuration state.
I use squashfs images on x86 within backfire 10.03 and saving config works for 
me (sysupgrade -v and webbased (webif)).

I not tested 10.03.1 or trunk on x86 yet but will do later.

 Would anyone be willing to work on this?  I might have a platform (like an
 Alix 2D13) I can contribute to the effort. I'd work on it, but don't know a
 lot about MTD, etc. But if someone is willing to walk me through it, I can
 make an attempt.
I can try find out your issue.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] patch for kernel-panic package

2011-12-22 Thread Christoph Thielecke
Hello,

yesterday I had the problem that a openwrt box (x86) has many processes with 
status D and reboot (even reboot -f) does not work. By default sysrq is not 
enabled in kernel and cant be made as module.

After some research someone in #openwrt got the idea to create a kernel panic 
(which works if automatic reboot on kernel panic is enabled, sysctl -n 
kernel.panic must have a value  0) via a module described at the page here 
(http://www.unix.com/unix-dummies-questions-answers/131850-simulating-kernel-panic.html).

I created a package which builds the kernel module panic.ko and after upload 
and insmod it and the box finally did a reboot.

I think this module could be useful if no reboot works/sysrq not enabled 
because it can be created after image creation and works with simple 
upload/insmod.

The patch for the package is attached.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/
diff -burN package2/kernel-panic/Makefile package/kernel-panic/Makefile
--- package.old/kernel-panic/Makefile	1970-01-01 01:00:00.0 +0100
+++ package/kernel-panic/Makefile	2011-12-22 08:52:27.267271121 +0100
@@ -0,0 +1,53 @@
+#
+# Copyright (C) 2008 OpenWrt.org
+#
+# This is free software, licensed under the GNU General Public License v2.
+# See /LICENSE for more information.
+#
+
+include $(TOPDIR)/rules.mk
+include $(INCLUDE_DIR)/kernel.mk
+
+PKG_NAME:=kernel-panic
+PKG_RELEASE:=1
+
+include $(INCLUDE_DIR)/package.mk
+
+define KernelPackage/kernel-panic
+  SUBMENU:=Other modules
+  TITLE:=Kernel Panic module
+  DEPENDS:=@LINUX_2_6
+  FILES:=$(PKG_BUILD_DIR)/panic.$(LINUX_KMOD_SUFFIX)
+  KCONFIG:=
+endef
+
+define KernelPackage/kernel-panic/description
+  Kernel module to generate a kernel panic
+endef
+
+EXTRA_KCONFIG:= \
+	CONFIG_KERNEL_PANIC=m
+
+EXTRA_CFLAGS:= \
+	$(patsubst CONFIG_%, -DCONFIG_%=1, $(patsubst %=m,%,$(filter %=m,$(EXTRA_KCONFIG \
+	$(patsubst CONFIG_%, -DCONFIG_%=1, $(patsubst %=y,%,$(filter %=y,$(EXTRA_KCONFIG \
+
+MAKE_OPTS:= \
+	ARCH=$(LINUX_KARCH) \
+	CROSS_COMPILE=$(TARGET_CROSS) \
+	SUBDIRS=$(PKG_BUILD_DIR) \
+	EXTRA_CFLAGS=$(EXTRA_CFLAGS) \
+	$(EXTRA_KCONFIG)
+
+define Build/Prepare
+	mkdir -p $(PKG_BUILD_DIR)
+	$(CP) ./src/* $(PKG_BUILD_DIR)/
+endef
+
+define Build/Compile
+	$(MAKE) -C $(LINUX_DIR) \
+		$(MAKE_OPTS) \
+		modules
+endef
+
+$(eval $(call KernelPackage,kernel-panic))
diff -burN package.old/kernel-panic/src/Kconfig package/kernel-panic/src/Kconfig
--- package.old/kernel-panic/src/Kconfig	1970-01-01 01:00:00.0 +0100
+++ package/kernel-panic/src/Kconfig	2011-12-22 08:47:30.879261754 +0100
@@ -0,0 +1,2 @@
+config KERNEL_PANIC
+	tristate Kernel Panic module
diff -burN package.old/kernel-panic/src/Makefile package/kernel-panic/src/Makefile
--- package.old/kernel-panic/src/Makefile	1970-01-01 01:00:00.0 +0100
+++ package/kernel-panic/src/Makefile	2011-12-22 08:54:11.959274430 +0100
@@ -0,0 +1 @@
+obj-${CONFIG_KERNEL_PANIC}	+= panic.o
diff -burN package.old/kernel-panic/src/panic.c package/kernel-panic/src/panic.c
--- package.old/kernel-panic/src/panic.c	1970-01-01 01:00:00.0 +0100
+++ package/kernel-panic/src/panic.c	2011-12-21 22:57:45.0 +0100
@@ -0,0 +1,10 @@
+// panic.c
+#include linux/module.h
+
+static int __init panic_init_module(void) {
+panic( panic has been called);
+}
+
+module_init(panic_init_module);
+MODULE_LICENSE(GPL);
+


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


Re: [OpenWrt-Devel] [PATCH] packages for updated e1000/e1000e driver from SF

2011-12-22 Thread Christoph Thielecke
Hello,

  here are the packages for updated e1000 and e1000e drivers from
  sourceforge.
 
  Please notice that you can only use one of the drivers kmod-e1000 or
  e1000 (kmod-e1000e or e1000e).

 Any particular reasons not to use the mainline e1000 and e1000e drivers?
Yes, the mainline driver is old and buggy. The updated ones have a lot of 
fixes.

I think these patches should go into package feeds only.


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel


[OpenWrt-Devel] [PATCH] add isc_dhclient package and add isc_dhclient support to base-files-network

2012-01-26 Thread Christoph Thielecke
Hello,

Sometimes I had problems with udhcpc. I decided to use dhclient then but the 
dhcp package contains only server and relay.

Now, here is the work:
The first patch (isc_dhcp_client_support.patch) adds the dhcp-client package 
and the second one (add_basefiles-network-isc_dhcp_client_support.patch) adds 
support in base-files-network for the isc dhclient (will be used instead of 
udhcpc if dhclient is available).


The patches are against trunk (r29910).


With best regards

Christoph
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/
diff -burN package.orig/base-files-network/files/lib/network/config.sh package/base-files-network/files/lib/network/config.sh
--- package.orig/base-files-network/files/lib/network/config.sh	2012-01-26 12:17:17.145214294 +0100
+++ package/base-files-network/files/lib/network/config.sh	2012-01-26 14:53:31.357124893 +0100
@@ -366,11 +366,11 @@
 			setup_interface_static $iface $config
 		;;
 		dhcp)
 			# kill running udhcpc instance
 			local pidfile=/var/run/dhcp-${iface}.pid
 
-			SERVICE_PID_FILE=$pidfile \
-			service_stop /sbin/udhcpc
+			SERVICE_PID_FILE=$pidfile
+			[ -x /sbin/dhclient ]  service_stop /sbin/dhclient || service_stop /sbin/udhcpc
 
 			local ipaddr netmask hostname proto1 clientid vendorid broadcast reqopts
 			config_get ipaddr $config ipaddr
@@ -400,6 +400,11 @@
 			}
 			[ $broadcast = 1 ]  broadcast=-O broadcast || broadcast=
 
+			[ -x /sbin/dhclient ]  {
+SERVICE_DAEMONIZE=$daemonize \
+SERVICE_PID_FILE=$pidfile \
+service_start /sbin/dhclient -q -lf /tmp/dhcp.leases -pf $pidfile -nw   $iface
+			}  ||  {
 			SERVICE_DAEMONIZE=$daemonize \
 			SERVICE_PID_FILE=$pidfile \
 			service_start /sbin/udhcpc -t 0 -i $iface \
@@ -409,6 +414,7 @@
 ${vendorid:+-V $vendorid} \
 -b -p $pidfile $broadcast \
 ${dhcpopts}
+			}
 		;;
 		none)
 			setup_interface_none $iface $config
@@ -436,7 +442,7 @@
 	remove_dns $config
 
 	SERVICE_PID_FILE=/var/run/dhcp-${ifname}.pid \
-	service_stop /sbin/udhcpc
+	[ -x /sbin/dhclient ]  sbin/dhclient -q -x -lf /tmp/dhcp.leases -pf $SERVICE_PID_FILE ${ifname} ; service_stop /sbin/dhclient || service_stop /sbin/udhcpc
 
 	uci -P /var/state revert network.$config
 }
@@ -366,11 +366,11 @@
 		;;
 		dhcp)
-			# kill running udhcpc instance
+			# kill running udhcpc/dhclient instance
 			local pidfile=/var/run/dhcp-${iface}.pid
 
-- 
Linux User Group Wernigerode
http://www.lug-wr.de/


signature.asc
Description: This is a digitally signed message part.
___
openwrt-devel mailing list
openwrt-devel@lists.openwrt.org
https://lists.openwrt.org/mailman/listinfo/openwrt-devel